#!/usr/bin/python

from PyQt4 import QtCore
from PyQt4.QtGui import *

import sys

sys.path.append(r'/usr/share/pyconverter')
import converter

class QtConverter(QWidget):

	def __init__(self, parent=None):
		# create a window
		QWidget.__init__(self, parent)
		self.setWindowTitle('Unit Converter v0.2 - QT')

		# create a grid to hold everything
		grid = QGridLayout()

		# instantiate conversion engine
		self.changing = False
		self.converter = converter.Converter(r'/usr/share/pyconverter')
#		self.converter = converter.Converter('.')

		# first row, conversion types
			# create label
		types_label = QLabel('Conversion Type:')
			# create combo box
		self.types = QComboBox()
		self.types.addItems(self.converter.getTypeList())
		self.connect(self.types, QtCore.SIGNAL('currentIndexChanged(int)'), self.loadFromToPick)
			# add to grid
		grid.addWidget(types_label, 0, 0)
		grid.addWidget(self.types, 0, 1)

		# second/third row, conversion 'from'
			# create combo box
		self.conv_f = QComboBox()
		self.connect(self.conv_f, QtCore.SIGNAL('currentIndexChanged(int)'), self.updateResults)
			# create line edit
		self.data_f = QLineEdit()
		self.data_f.setValidator(QDoubleValidator(self.data_f))
			# add to grid
		grid.addWidget(QLabel('From:'), 1, 0)
		grid.addWidget(self.conv_f, 1, 1)
		grid.addWidget(self.data_f, 2, 0, 1, -1)

		# fourth/fifth row, conversion 'to'
			# create combo box
		self.conv_t = QComboBox()
		self.connect(self.conv_t, QtCore.SIGNAL('currentIndexChanged(int)'), self.updateResults)
			# create results label
		self.data_t = QLabel('?')
			# add to grid
		grid.addWidget(QLabel('To:'), 3, 0)
		grid.addWidget(self.conv_t, 3, 1)
		grid.addWidget(self.data_t, 4, 0, 1, -1)

		# sixth row, conversion button
			# create button
		btn_ok = QPushButton('Convert')
		self.connect(btn_ok, QtCore.SIGNAL('clicked()'), self.doConversion)
			# add to grid
		grid.addWidget(btn_ok, 5, 0, 1, -1)

		# display everything
		self.setLayout(grid)
		self.types.setCurrentIndex(0)
		self.loadFromToPick(0)

	def doConversion(self):
		# abort if we're changing the type
		if self.changing:
			return

		# get the string for 'from' and 'to'
		old = str(self.conv_f.currentText())
		new = str(self.conv_t.currentText())

		# get the value
		val = str(self.data_f.text())

		# update the result
		self.data_t.setText(self.converter.doConversion(old, new, val))

	def updateResults(self, index):
		self.doConversion()

	def loadFromToPick(self, index):
		# keep the changing pickers from triggering their signals
		self.changing = True

		# get the choices
		self.converter.setType(index)
		pick = self.converter.getUnitList()

		# update the 'from' picker
		self.conv_f.clear()
		self.conv_f.addItems(pick)
		self.conv_f.setCurrentIndex(0)

		# update the 'to' picker
		self.conv_t.clear()
		self.conv_t.addItems(pick)
		self.conv_t.setCurrentIndex(1)

		# okay, back to normal
		self.changing = False
		self.doConversion()

# run the program
if __name__ == '__main__':
	app = QApplication(sys.argv)
	win = QtConverter()
	win.show()
	sys.exit(app.exec_())
